# py-ina238

Python driver for the
[Texas Instruments INA238 85-V, 16-Bit, High-Precision Power Monitor With I2C Interface](https://www.ti.com/product/INA238)

## Installation

Latest release:

```bash
pip install py-ina238
```

From git clone:
```bash
git clone https://github.com/GSI-HPC/py-ina238
cd py-ina238
pip install -e .
```

## License

`py-ina238` is distributed under the terms of the
[GNU LGPLv3](https://choosealicense.com/licenses/lgpl-3.0).
